# Generated by Django 3.1.1 on 2020-11-02 08:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qronos_django', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='qronosimportlog',
            name='import_type',
            field=models.CharField(choices=[('Tracker', 'Tracker'), ('Stage', 'Stage'), ('Delete', 'Delete')], max_length=20),
        ),
    ]



from django.conf import settings

DEFAULT_QRONOS_HOST = "dev.qronos.xyz"
DEFAULT_QRONOS_USER = ""
DEFAULT_QRONOS_PASSWORD = ""
DEFAULT_QRONOS_TOKEN_CACHE_KEY = "QRONOS_TOKEN"
DEFAULT_QRONOS_TOKEN_CACHE_FRACTION = 0.8
DEFAULT_QRONOS_LOGGING = True
DEFAULT_QRONOS_ID_LOGGING = False
DEFAULT_QRONOS_DATA_LOGGING = False

QRONOS_HOST = getattr(settings, "QRONOS_HOST", DEFAULT_QRONOS_HOST)
QRONOS_USER = getattr(settings, "QRONOS_USER", DEFAULT_QRONOS_USER)
QRONOS_PASSWORD = getattr(settings, "QRONOS_PASSWORD", DEFAULT_QRONOS_PASSWORD)
QRONOS_TOKEN_CACHE_KEY = getattr(settings, "QRONOS_TOKEN_CACHE_KEY", DEFAULT_QRONOS_TOKEN_CACHE_KEY)
QRONOS_TOKEN_CACHE_FRACTION = getattr(settings, "QRONOS_TOKEN_CACHE_FRACTION", DEFAULT_QRONOS_TOKEN_CACHE_FRACTION)
QRONOS_LOGGING = getattr(settings, "QRONOS_LOGGING", DEFAULT_QRONOS_LOGGING)
QRONOS_ID_LOGGING = getattr(settings, "QRONOS_ID_LOGGING", DEFAULT_QRONOS_ID_LOGGING)
QRONOS_DATA_LOGGING = getattr(settings, "QRONOS_DATA_LOGGING", DEFAULT_QRONOS_DATA_LOGGING)



from django.core.cache import cache
from django.utils import timezone
from qronos import QRonosClient

from qronos_django.settings import QRONOS_HOST, QRONOS_USER, QRONOS_PASSWORD, QRONOS_TOKEN_CACHE_FRACTION, \
    QRONOS_TOKEN_CACHE_KEY


def get_qronos_client():
    qronos_token = cache.get(QRONOS_TOKEN_CACHE_KEY)
    if qronos_token:
        return QRonosClient(host=QRONOS_HOST, token=qronos_token)
    qronos = QRonosClient(host=QRONOS_HOST)
    token, expiry = qronos.login(QRONOS_USER, QRONOS_PASSWORD)
    if QRONOS_TOKEN_CACHE_FRACTION:
        timeout = (expiry - timezone.now()).total_seconds() * QRONOS_TOKEN_CACHE_FRACTION
        cache.set(QRONOS_TOKEN_CACHE_KEY, token, timeout)
    return qronos



from django.db import models
from django.utils import timezone
from qronos import QRonosError

from qronos_django.connection import get_qronos_client


class QRonosImportLog(models.Model):

    class QRonosImportType(models.TextChoices):
        TRACKER = "Tracker", "Tracker"
        STAGE = "Stage", "Stage"
        DELETE = "Delete", "Delete"

    import_type = models.CharField(max_length=20, choices=QRonosImportType.choices)
    job_id = models.IntegerField(blank=True, null=True)
    status = models.CharField(max_length=20, default="UNKNOWN")
    status_updated = models.DateTimeField(blank=True, null=True)
    id_log = models.TextField(blank=True)
    data_log = models.TextField(blank=True)
    error_log = models.TextField(blank=True)
    sent = models.DateTimeField(auto_now_add=True)

    def update_import_status(self, qronos=None):
        if not qronos:
            qronos = get_qronos_client()
        try:
            status = qronos.import_status(self.job_id)
        except QRonosError:
            status = "UNKNOWN"
        finally:
            self.status = status
            self.status_updated = timezone.now()
            self.save()
        return status

    class Meta:
        verbose_name = "QRonos Import Log"
        verbose_name_plural = "QRonos Import Logs"

    def __str__(self):
        return f"QRonos Import {self.id} (TP: {self.job_id or '-'})"



# Generated by Django 3.1.1 on 2020-10-28 16:00

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='QRonosImportLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('import_type', models.CharField(choices=[('Tracker', 'Tracker'), ('Stage', 'Stage')], max_length=20)),
                ('job_id', models.IntegerField(blank=True, null=True)),
                ('status', models.CharField(default='UNKNOWN', max_length=20)),
                ('status_updated', models.DateTimeField(blank=True, null=True)),
                ('id_log', models.TextField(blank=True)),
                ('data_log', models.TextField(blank=True)),
                ('error_log', models.TextField(blank=True)),
                ('sent', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'verbose_name': 'QRonos Import Log',
                'verbose_name_plural': 'QRonos Import Logs',
            },
        ),
    ]
